@@ -2,10 +2,11 @@
 The main entry point for the mitosheet package, this command
 line interface allows you to set some toggles in the user.json
 """
-from mitosheet.user.db import set_user_field
 import sys
+
+from mitosheet.user.db import set_user_field
 from mitosheet.user import initialize_user
-from mitosheet.user.schemas import UJ_MITOSHEET_TELEMETRY, UJ_USER_EMAIL
+from mitosheet.user.schemas import UJ_MITOSHEET_PRO, UJ_MITOSHEET_TELEMETRY, UJ_USER_EMAIL
 from mitosheet.startup.startup_utils import create_startup_file, remove_startup_file
 
 def main():
@@ -13,6 +14,7 @@ def main():
     Currently, the main usage of this function is:
     python -m mitosheet turnofflogging
     python -m mitosheet turnonlogging
+    python -m mitosheet turnoffpro
     python -m mitosheet turnoffdataframebutton
     python -m mitosheet turnondataframebutton
 
@@ -33,6 +35,10 @@ def main():
             print("Turning on all logging")
             set_user_field(UJ_MITOSHEET_TELEMETRY, True)
             print("Logging turned on!")
+        if sys.argv[-1] == 'turnoffpro':
+            print("Turning on Mitosheet pro")
+            set_user_field(UJ_MITOSHEET_PRO, False)
+            print("Mitosheet Pro is false!")
         if sys.argv[-1] == 'clearemail':
             print("Clearing email")
             set_user_field(UJ_USER_EMAIL, '')
