@@ -9,19 +9,16 @@ Contains handlers for the Mito API
 """
 from queue import Queue
 from threading import Thread
-
 from mitosheet.api.get_column_describe import get_column_describe
 from mitosheet.api.get_column_dtype import get_column_dtype
 from mitosheet.api.get_datafiles import get_datafiles
-from mitosheet.api.get_dateframe_as_csv import get_dataframe_as_csv
-from mitosheet.api.get_dateframe_as_excel import get_dataframe_as_excel
+from mitosheet.api.get_dataframe_as_csv import get_dataframe_as_csv
+from mitosheet.api.get_dataframe_as_excel import get_dataframe_as_excel
 from mitosheet.api.get_excel_file_metadata import get_excel_file_metadata
 from mitosheet.api.get_path_contents import get_path_contents
 from mitosheet.api.get_path_join import get_path_join
 from mitosheet.api.get_pivot_params import get_pivot_params
 from mitosheet.api.get_search_matches import get_search_matches
-from mitosheet.api.get_sheet_data import get_sheet_data
-from mitosheet.api.get_starting_formula import get_starting_formula
 from mitosheet.api.get_unique_value_counts import get_unique_value_counts
 from mitosheet.api.graph import get_graph
 from mitosheet.mito_analytics import log_event_processed
@@ -29,7 +26,7 @@ from mitosheet.mito_analytics import log_event_processed
 # As the column summary statistics tab does three calls, we defaulted to this max
 MAX_QUEUED_API_CALLS = 3
 
-# NOTE: BE CAREFUL WITH THIS. When in development mode, you can set it
+# NOTE: BE CAREFUL WITH THIS. When in development mode, you can set it to False
 # so the API calls are handled in the main thread, to make printing easy
 THREADED = True
 
@@ -105,8 +102,6 @@ def handle_api_event(send, event, steps_manager):
     API must return the same ID that the incoming message contains,
     so that the frontend knows how to match the responses.
     """    
-
-    # And then handle it
     if event['type'] == 'datafiles':
         result = get_datafiles(event)
     elif event['type'] == 'get_path_contents':
@@ -129,12 +124,8 @@ def handle_api_event(send, event, steps_manager):
         result = get_unique_value_counts(event, steps_manager)
     elif event['type'] == 'get_search_matches':
         result = get_search_matches(event, steps_manager)
-    elif event['type'] == 'get_cell_values':
-        result = get_sheet_data(event, steps_manager)
     elif event['type'] == 'get_dataframe_as_excel':
         result = get_dataframe_as_excel(event, steps_manager)
-    elif event['type'] == 'get_starting_formula':
-        result = get_starting_formula(event, steps_manager)
     else:
         raise Exception(f'Event: {event} is not a valid API call')
     
