@@ -1,5 +1,7 @@
-import pandas as pd
 import json
+import os
+import pandas as pd
+
 
 def get_excel_file_metadata(event, steps_manager):
     """
@@ -15,7 +17,8 @@ def get_excel_file_metadata(event, steps_manager):
     file = pd.ExcelFile(file_name)
     sheet_names = file.sheet_names
     return json.dumps({
-        'sheet_names': sheet_names
+        'sheet_names': sheet_names,
+        'size': os.path.getsize(file_name)
     })
 
 
