@@ -3,7 +3,7 @@ from mitosheet.utils import df_to_json_dumpsable
 
 def get_sheet_data(event, steps_manager):
     """
-    Returns the sheet data for 1k cells starting a starting_row_index. This
+    Returns the sheet data for 1k cells starting at starting_row_index. This
     is the function that allows us to lazy-load data into the sheet
 
     Params:
@@ -28,6 +28,7 @@ def get_sheet_data(event, steps_manager):
         steps_manager.curr_step.column_filters[sheet_index],
         steps_manager.curr_step.column_type[sheet_index],
         steps_manager.curr_step.column_ids.column_header_to_column_id[sheet_index],
+        steps_manager.curr_step.column_format_types[sheet_index],
         max_length=1000,
         starting_index=starting_row_index
     ))
\ No newline at end of file
