@@ -25,6 +25,11 @@ import subprocess
 
 from mitosheet.parser import parse_formula
 
+try:
+    from jupyterlab import __version__ as jupyterlab_version
+except:
+    jupyterlab_version = 'No JupyterLab'
+
 import analytics
 # Write key taken from segement.com
 analytics.write_key = '6I7ptc5wcIGC4WZ0N1t0NXvvAbjRGUgX' 
@@ -35,22 +40,14 @@ from mitosheet.user import (
 )
 from mitosheet.user import get_user_field, is_local_deployment, is_running_test, is_local_deployment
 from mitosheet._version import __version__
-from mitosheet.errors import get_recent_traceback, get_recent_traceback_as_list
-
-# We cache if logging is turned on to make sure we dont
-# make unecessary calls to read the user.json
-TELEMETRY_TURNED_ON = None
+from mitosheet.errors import get_recent_traceback_as_list
 
 def telemetry_turned_on():
     """
     Helper function that tells if you if logging is turned on or
     turned off on the entire Mito instance
     """
-    global TELEMETRY_TURNED_ON
-    if TELEMETRY_TURNED_ON is None:
-        TELEMETRY_TURNED_ON = get_user_field(UJ_MITOSHEET_TELEMETRY)
-    
-    return TELEMETRY_TURNED_ON
+    return get_user_field(UJ_MITOSHEET_TELEMETRY)
 
 # When we anonymize, we use some combination of these words
 # to construct new private words
@@ -104,20 +101,11 @@ def anonymize_formula(formula, sheet_index, steps_manager=None):
     
     return formula
 
-def get_jupyterlab_version():
-    try:
-        from jupyterlab import __version__ as jupyterlab_version
-    except:
-        jupyterlab_version = 'No JupyterLab'
-
-    return jupyterlab_version
-
 def get_jupyter_labextension_list():
     """
     This gets the current output from the command `jupyter labextension list`
     which is very helpful in debugging the users installation.
 
-
     Because this function can be _very_ expensive to run for some users, we should
     only use this sparingly and not during every log event!
 
@@ -174,10 +162,9 @@ def log(log_event, params=None, steps_manager=None):
     # Add the python properties to every log event we can
     python_properties = {
         'version_python': sys.version_info,
-        'version_jupyterlab': get_jupyterlab_version(),
+        'version_jupyterlab': jupyterlab_version,
         'version_mito': __version__ 
     }
-
     
     params = dict(
         **params,
@@ -185,8 +172,8 @@ def log(log_event, params=None, steps_manager=None):
     )
 
     # Private params are where we _make sure_ that no private
-    # user data leaves the users machine. We replace any potentially
-    # non-private params with private versions of them
+    # user data leaves the user's machine. We replace any potentially
+    # non-private params with private versions of them.
     private_params = {}
     try:
         for key, value in params.items():
@@ -209,8 +196,8 @@ def log(log_event, params=None, steps_manager=None):
                 # Just count the number of files, instead of keeping their names
                 private_params[key] = len(value)
             elif 'values' in key:
-                # for pivot params, we anonymize the column headers
-                # and keep the agg functions
+                # For pivot params, we anonymize the column headers
+                # and keep the agg functions.
                 private_params[key] = {anonymize_word(k): v for k, v in value.items()}
             elif 'filters' in key:
                 # For filters, we get rid of the values, but keep the conditions
@@ -275,7 +262,6 @@ def identify():
     intended_behavior = get_user_field(UJ_INTENDED_BEHAVIOR)
     feedbacks = get_user_field(UJ_FEEDBACKS)
     local = is_local_deployment()
-    jupyterlab_version = get_jupyterlab_version()
     operating_system = platform.system()
 
     
@@ -358,9 +344,9 @@ def log_event_processed(event, steps_manager, failed=False, edit_error=None):
         # NOTE: we keep this as underscored with wsc for backwards compatibility with
         # our logs!
         steps_manager_properties = {
-            # NOTE: analysis name is the UUID that mito saves the analysis under
+            # NOTE: Analysis name is the UUID that mito saves the analysis under
             'wsc_analysis_name': steps_manager.analysis_name,
-            # NOTE: change this when code fixing this logic is merged in
+            # NOTE: Change this when code fixing this logic is merged in
             'wsc_data_type_in_mito': str(steps_manager.data_type_in_mito),
             'wsc_local': is_local_deployment(),
             'wsc_curr_step_idx': steps_manager.curr_step_idx,
