@@ -7,29 +7,21 @@
 Main file containing the mito widget.
 """
 import json
-from mitosheet.saved_analyses.save_utils import read_saved_analysis_names
+import pandas as pd
+import random
+from ipywidgets import DOMWidget
+import traitlets as t
+
+from mitosheet.mito_analytics import log, log_event_processed, log_recent_error, telemetry_turned_on
 from mitosheet.step_performers import STEP_TYPE_TO_USAGE_TRIGGERED_FEEDBACK_ID
 from mitosheet.user.schemas import UJ_MITOSHEET_LAST_FIFTY_USAGES, UJ_RECEIVED_TOURS, UJ_USER_EMAIL
 from mitosheet.user.db import get_user_field
 from mitosheet.user.utils import is_pro
 from mitosheet.api import API
-from mitosheet.mito_analytics import log, log_event_processed, log_recent_error, telemetry_turned_on
-import pandas as pd
-import random
-
-from ipywidgets import DOMWidget
-import traitlets as t
-
 from mitosheet._frontend import module_name, module_version
-from mitosheet.errors import MitoError, get_recent_traceback, get_recent_traceback_as_list
-from mitosheet.saved_analyses import (
-    read_and_upgrade_analysis, 
-    write_analysis,
-    saved_analysis_names_json
-)
-
+from mitosheet.errors import MitoError, get_recent_traceback
+from mitosheet.saved_analyses import write_analysis
 from mitosheet.steps_manager import StepsManager
-
 from mitosheet.user import is_local_deployment, should_upgrade_mitosheet
 from mitosheet.data_in_mito import DataTypeInMito
 
@@ -72,7 +64,6 @@ class MitoWidget(DOMWidget):
         # have to recompute them on each update
         self.num_usages = len(get_user_field(UJ_MITOSHEET_LAST_FIFTY_USAGES))
         self.usage_triggered_feedback_id = ''
-        self.is_pro = is_pro()
         self.is_local_deployment = is_local_deployment()
         self.should_upgrade_mitosheet = should_upgrade_mitosheet()
         self.received_tours = get_user_field(UJ_RECEIVED_TOURS)
@@ -96,9 +87,8 @@ class MitoWidget(DOMWidget):
             # Dynamic, update each time
             'userEmail': get_user_field(UJ_USER_EMAIL),
             'receivedTours': get_user_field(UJ_RECEIVED_TOURS),
-            'savedAnalysisNames': read_saved_analysis_names(),
+            'isPro': is_pro(),
             # Static over a single analysis
-            'isPro': self.is_pro,
             'isLocalDeployment': self.is_local_deployment,
             'shouldUpgradeMitosheet': self.should_upgrade_mitosheet,
             'numUsages': self.num_usages,
@@ -282,7 +272,7 @@ def sheet(
 
     Then, restart your JupyterLab instance, and refresh your browser. Mito should now render.
 
-    NOTE: if you have any issues with installation, please book a demo at https://hubs.ly/H0FL1920
+    NOTE: if you have any issues with installation, please email jake@sagacollab.com
     """
     try:
         # We pass in the dataframes directly to the widget
