@@ -13,11 +13,9 @@ from mitosheet.step import Step
 import os
 import json
 from typing import List
-
 from mitosheet._version import __version__
 from mitosheet.mito_analytics import log
 
-
 # Where all global .mito files are stored
 MITO_FOLDER = os.path.expanduser("~/.mito")
 
@@ -114,32 +112,6 @@ def rename_saved_analysis(old_analysis_name, new_analysis_name):
         raise Exception(f'Invalid rename, with old and new analysis are {old_analysis_name} and {new_analysis_name}')
 
 
-def read_saved_analysis_names():
-    """
-    Reads the names of all the analyses saved by the user.
-
-    Does not return any of the auto-saved analyses!
-    """
-    if not os.path.exists(SAVED_ANALYSIS_FOLDER):
-        return []
-
-    file_names = [
-        f for f in os.listdir(SAVED_ANALYSIS_FOLDER) 
-        if os.path.isfile(os.path.join(SAVED_ANALYSIS_FOLDER, f))
-        and not f.startswith('UUID-')
-    ]
-
-    # We make sure they are in alphabetical order!
-    file_names.sort()
-
-    return [
-        file_name[:-5] for file_name in file_names 
-        if file_name.endswith('.json')
-    ]
-
-def saved_analysis_names_json():
-    return json.dumps(read_saved_analysis_names())
-
 def write_saved_analysis(analysis_path, steps_data, version=__version__):
     with open(analysis_path, 'w+') as f:
         saved_analysis = {
