@@ -14,10 +14,10 @@ NOTE: This file is alphabetical order!
 """
 import functools
 from typing import Tuple
-from mitosheet.sheet_functions.types.utils import NUMBER_SERIES, STRING_SERIES
 import pandas as pd
 import numpy as np
 
+from mitosheet.sheet_functions.types.utils import NUMBER_SERIES, STRING_SERIES
 from mitosheet.sheet_functions.types.decorators import convert_arg_to_series_type, convert_args_to_series_type, filter_nans, cast_output, handle_sheet_function_errors
 from mitosheet.sheet_functions.sheet_function_utils import fill_series_with_one_index, try_extend_series_to_index
 
@@ -36,7 +36,7 @@ def CLEAN(series) -> pd.Series:
         "function": "CLEAN",
         "description": "Returns the text with the non-printable ASCII characters removed.",
         "examples": [
-            "CLEAN('ABC\\n')"
+            "CLEAN(A)"
         ],
         "syntax": "CLEAN(string)",
         "syntax_elements": [{
