@@ -131,7 +131,7 @@ def filter_nans(sheet_function):
 
         original_index, non_nan_index = get_nan_indexes_metadata(*args)
             
-        # for each arg that is an instance of a pd.series, filter out the nan_indexes
+        # For each arg that is an instance of a pd.series, filter out the nan_indexes
         new_args = []
         for arg in args:
             if isinstance(arg, pd.Series):
@@ -161,7 +161,7 @@ def fill_nans(
 
     NOTE: this sometimes makes sense to call before the type casting decorators, and sometimes
     after (depending on what you are trying to accomplish). It does likely make sense to call 
-    _after_ the type casting code, as 
+    _after_ the type casting code.
     """
     def wrap(sheet_function):
         @wraps(sheet_function)
