@@ -8,11 +8,12 @@
 Utilities to help with type functions
 """
 
-from mitosheet.sheet_functions.sheet_function_utils import is_series_of_constant
 from typing import Any, Set, Tuple, Union
 import pandas as pd
 import numpy as np
 
+from mitosheet.sheet_functions.sheet_function_utils import is_series_of_constant
+
 # Because type(1) = int, thus 1 is a 'number' in the Mito type system
 MITO_PRIMITIVE_TYPE_MAPPING = {
     'boolean': [bool],
@@ -59,49 +60,20 @@ def is_none_type(value: Union[str, None]):
     """
     return True if value is None or str(value).lower() in ['nan', 'nat'] else False
 
-def get_float_columns(df: pd.DataFrame):
-    """
-    Returns all the float column_headers in the
-    passed dataframe
-    """
-    float_columns = []
+def get_float_dt_td_columns(df: pd.DataFrame):
+    float_columns, date_columns, timedelta_columns = [], [], []
     for column_header in df.columns:
-        if is_float_dtype(str(df[column_header].dtype)):
+        dtype = str(df[column_header].dtype)
+        # NOTE: these functions are called frequently, so we put them in 
+        # the order they are most likely to be true in, so we can short out
+        if is_float_dtype(dtype):
             float_columns.append(column_header)
-    return float_columns
-
-def get_string_columns(df: pd.DataFrame):
-    """
-    Returns all the string column_headers in the
-    passed dataframe
-    """
-    string_columns = []
-    for column_header in df.columns:
-        if is_string_dtype(str(df[column_header].dtype)):
-            string_columns.append(column_header)
-    return string_columns
-
-def get_datetime_columns(df: pd.DataFrame):
-    """
-    Returns all the datetime column_headers in the
-    passed dataframe
-    """
-    datetime_columns = []
-    for column_header in df.columns:
-        if is_datetime_dtype(str(df[column_header].dtype)):
-            datetime_columns.append(column_header)
-    return datetime_columns
-
-def get_timedelta_columns(df: pd.DataFrame):
-    """
-    Returns all the timedelta column_headers in the
-    passed dataframe
-    """
-    timedelta_columns = []
-    for column_header in df.columns:
-        if is_timedelta_dtype(str(df[column_header].dtype)):
+        elif is_datetime_dtype(dtype):
+            date_columns.append(column_header)
+        elif is_timedelta_dtype(dtype):
             timedelta_columns.append(column_header)
-    return timedelta_columns
+
+    return float_columns, date_columns, timedelta_columns
 
 def get_mito_type(obj):
 
