@@ -6,7 +6,7 @@
 
 from copy import deepcopy
 from collections import OrderedDict
-from typing import List
+from typing import List, Dict
 import pandas as pd
 
 from mitosheet.sheet_functions.types.utils import get_mito_type
@@ -19,6 +19,15 @@ DATAFRAME_SOURCE_PIVOTED = 'pivoted' # created through a pivot
 DATAFRAME_SOURCE_MERGED = 'merged' # created through a merge
 DATAFRAME_SOURCE_DUPLICATED = 'duplicated' # created through a sheet duplication
 
+# Constants used for formatting. Defined here to avoid circular imports
+FORMAT_DEFAULT = 'default'
+FORMAT_PLAIN_TEXT = 'plain text'
+FORMAT_PERCENTAGE = 'percentage'
+FORMAT_ACCOUNTING = 'accounting'
+FORMAT_CURRENCY = 'currency'
+FORMAT_ROUND_DECIMALS = 'round decimals'
+FORMAT_K_M_B = 'k_m_b'
+FORMAT_SCIENTIFIC_NOTATION = 'scientific notation'
 
 class State():
     """
@@ -41,7 +50,8 @@ class State():
             column_spreadsheet_code=None,
             column_python_code=None,
             column_evaluation_graph=None,
-            column_filters=None
+            column_filters=None,
+            column_format_types: List[Dict[str, Dict[str, str]]]=None
         ):
 
         # The dataframes that are in the state
@@ -100,6 +110,10 @@ class State():
             for sheet_index in range(len(dfs))
         ]
 
+        self.column_format_types = column_format_types if column_format_types is not None else [
+            {column_id: {'type': 'default'} for column_id in self.column_ids.get_column_ids(sheet_index)} 
+            for sheet_index in range(len(dfs))
+        ]
     
     def __copy__(self):
         """
@@ -116,7 +130,8 @@ class State():
             column_spreadsheet_code=deepcopy(self.column_spreadsheet_code),
             column_python_code=deepcopy(self.column_python_code),
             column_evaluation_graph=deepcopy(self.column_evaluation_graph),
-            column_filters=deepcopy(self.column_filters)
+            column_filters=deepcopy(self.column_filters),
+            column_format_types=deepcopy(self.column_format_types)
         )
 
 
@@ -135,7 +150,8 @@ class State():
             column_spreadsheet_code=deepcopy(self.column_spreadsheet_code),
             column_python_code=deepcopy(self.column_python_code),
             column_evaluation_graph=deepcopy(self.column_evaluation_graph),
-            column_filters=deepcopy(self.column_filters)
+            column_filters=deepcopy(self.column_filters),
+            column_format_types=deepcopy(self.column_format_types)
         )
 
     def add_df_to_state(
@@ -144,6 +160,7 @@ class State():
             df_source: str, 
             sheet_index=None,
             df_name=None,
+            format_types=None,
             use_deprecated_id_algorithm: bool=False
         ):
         """
@@ -176,6 +193,7 @@ class State():
             self.column_python_code.append({column_id: '' for column_id in column_ids})
             self.column_evaluation_graph.append({column_id: set() for column_id in column_ids})
             self.column_filters.append({column_id: {'operator':'And', 'filters': []} for column_id in column_ids})
+            self.column_format_types.append({column_id: {'type': FORMAT_DEFAULT} for column_id in column_ids} if format_types is None else format_types)
 
             # Return the index of this sheet
             return len(self.dfs) - 1
@@ -201,6 +219,7 @@ class State():
             self.column_python_code[sheet_index] = {column_id: '' for column_id in column_ids}
             self.column_evaluation_graph[sheet_index] = {column_id: set() for column_id in column_ids}
             self.column_filters[sheet_index] = {column_id: {'operator':'And', 'filters': []} for column_id in column_ids}
+            self.column_format_types[sheet_index] = {column_id: {'type': FORMAT_DEFAULT} for column_id in column_ids} if format_types is None else format_types
 
             # Return the index of this sheet
             return sheet_index
