@@ -1,10 +1,8 @@
-
+from typing import Any, Dict, List, Optional, Type
 
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.step_performers.column_steps.set_column_formula import SetColumnFormulaStepPerformer
 from mitosheet.step_performers.filter import FilterStepPerformer
-from typing import Any, Dict, List, Optional, Type
-
 from mitosheet.state import State
 from mitosheet.step_performers import STEP_TYPE_TO_STEP_PERFORMER
 
@@ -98,6 +96,10 @@ class Step:
     def column_filters(self):
         return self.post_state.column_filters
 
+    @property
+    def column_format_types(self):
+        return self.post_state.column_format_types
+
     @property
     def step_performer(self) -> Type[StepPerformer]:
         """
@@ -173,7 +175,6 @@ class Step:
         if len(all_steps_before_this_step) > 0:
             previous_step: Step = all_steps_before_this_step[-1]
             
-            
             # Check (3)
             if self.step_type == SetColumnFormulaStepPerformer.step_type():
                 if self.step_type == previous_step.step_type \
