@@ -24,6 +24,7 @@ from mitosheet.step_performers.merge import MergeStepPerformer
 from mitosheet.step_performers.column_steps.delete_column import DeleteColumnStepPerformer
 from mitosheet.step_performers.column_steps.rename_column import RenameColumnStepPerformer
 from mitosheet.step_performers.column_steps.change_column_dtype import ChangeColumnDtypeStepPerformer
+from mitosheet.step_performers.column_steps.change_column_format import ChangeColumnFormatStepPerformer
 from mitosheet.step_performers.import_steps.simple_import import SimpleImportStepPerformer
 from mitosheet.step_performers.dataframe_steps.dataframe_delete import DataframeDeleteStepPerformer
 from mitosheet.step_performers.dataframe_steps.dataframe_duplicate import DataframeDuplicateStepPerformer
@@ -41,6 +42,7 @@ STEP_PERFORMERS: List[Type[StepPerformer]] = [
     AddColumnStepPerformer,
     SetColumnFormulaStepPerformer,
     ChangeColumnDtypeStepPerformer,
+    ChangeColumnFormatStepPerformer,
     MergeStepPerformer,
     DeleteColumnStepPerformer,
     RenameColumnStepPerformer,
