@@ -7,7 +7,7 @@
 
 import json
 from copy import deepcopy
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Set, Tuple
 
 from mitosheet.state import State
 from mitosheet.step_performers.bulk_old_rename.deprecated_utils import \
@@ -122,3 +122,10 @@ class BulkOldRenameStepPerformer(StepPerformer):
         **params
     ) -> str:
         return f'Renamed headers for compatibility with previous Mito versions'
+
+    @classmethod
+    def get_modified_dataframe_indexes( # type: ignore
+        cls, 
+        **params
+    ) -> Set[int]:
+        return set() # changes all dataframes
\ No newline at end of file
