@@ -5,11 +5,11 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import deepcopy
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Set, Tuple
 
 from mitosheet.errors import make_column_exists_error, make_no_sheet_error
 from mitosheet.sheet_functions.types.utils import NUMBER_SERIES
-from mitosheet.state import State
+from mitosheet.state import FORMAT_DEFAULT, State
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.transpiler.transpile_utils import column_header_to_transpiled_code
 
@@ -72,6 +72,7 @@ class AddColumnStepPerformer(StepPerformer):
         post_state.column_python_code[sheet_index][column_id] = f'df[\'{column_header}\'] = 0'
         post_state.column_evaluation_graph[sheet_index][column_id] = set()
         post_state.column_filters[sheet_index][column_id] = {'operator': 'And', 'filters': []}
+        post_state.column_format_types[sheet_index][column_id] = {'type': FORMAT_DEFAULT}
             
         # Update the dataframe
         post_state.dfs[sheet_index].insert(column_header_index, column_header, 0)
@@ -109,3 +110,13 @@ class AddColumnStepPerformer(StepPerformer):
             df_name = df_names[sheet_index]
             return f'Added column {column_header} to {df_name}'
         return f'Added column {column_header}' 
+
+    @classmethod
+    def get_modified_dataframe_indexes( # type: ignore
+        cls, 
+        sheet_index: int,
+        column_header: str,
+        column_header_index: int,
+        **params
+    ) -> Set[int]:
+        return {sheet_index}
\ No newline at end of file
