@@ -5,9 +5,9 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import copy
-from typing import Any, Dict, List, Optional, Tuple
-
+from typing import Any, Dict, List, Optional, Set, Tuple
 import pandas as pd
+
 from mitosheet.errors import get_recent_traceback, make_invalid_column_type_change_error
 from mitosheet.mito_analytics import log
 from mitosheet.sheet_functions.types.to_boolean_series import to_boolean_series
@@ -22,7 +22,7 @@ from mitosheet.sheet_functions.types.utils import (get_datetime_format,
                                                    is_int_dtype,
                                                    is_string_dtype,
                                                    is_timedelta_dtype)
-from mitosheet.state import State
+from mitosheet.state import FORMAT_DEFAULT, State
 from mitosheet.step_performers.column_steps.set_column_formula import (
     refresh_dependant_columns, transpile_dependant_columns)
 from mitosheet.step_performers.step_performer import StepPerformer
@@ -203,7 +203,11 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
             # We update the column, as well as the type of the column
             post_state.dfs[sheet_index][column_header] = new_column
             post_state.column_type[sheet_index][column_id] = get_mito_type(new_column)
-            
+
+            # If we're changing between number columns, we keep the formatting on the column. Otherwise, we remove it
+            if not ((is_int_dtype(old_dtype) or is_float_dtype(old_dtype)) and (is_int_dtype(new_dtype) or is_float_dtype(new_dtype))):
+                post_state.column_format_types[sheet_index][column_id] = {'type': FORMAT_DEFAULT}
+                
             refresh_dependant_columns(post_state, post_state.dfs[sheet_index], sheet_index)
 
             return post_state, None
@@ -353,3 +357,14 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
         **params
     ) -> str:
         return f'Changed {column_id} from {old_dtype} to {new_dtype}'
+
+    @classmethod
+    def get_modified_dataframe_indexes( # type: ignore
+        cls, 
+        sheet_index: int,
+        column_id: str,
+        old_dtype: str,
+        new_dtype: str,
+        **params
+    ) -> Set[int]:
+        return {sheet_index}
\ No newline at end of file
