@@ -5,7 +5,7 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import deepcopy
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Set, Tuple
 
 from mitosheet.errors import make_invalid_column_delete_error
 from mitosheet.state import State
@@ -88,6 +88,14 @@ class DeleteColumnStepPerformer(StepPerformer):
             return f'Deleted column{"s" if len(column_ids) > 1 else ""} {formated_column_ids} from {df_name}'
         return f'Deleted column{"s" if len(column_ids) > 1 else ""} {formated_column_ids}'
 
+    @classmethod
+    def get_modified_dataframe_indexes( # type: ignore
+        cls, 
+        sheet_index: int,
+        column_ids: List[str],
+        **params
+    ) -> Set[int]:
+        return {sheet_index}
 
 def delete_column_ids(
     state: State,
@@ -145,6 +153,8 @@ def _delete_column_id(
     del state.column_spreadsheet_code[sheet_index][column_id]
     del state.column_python_code[sheet_index][column_id]
     del state.column_evaluation_graph[sheet_index][column_id]
+    del state.column_format_types[sheet_index][column_id]
+
     # We also have to delete the places in the graph where this node is 
     for dependents in state.column_evaluation_graph[sheet_index].values():
         if column_id in dependents:
