@@ -58,7 +58,7 @@ class RenameColumnStepPerformer(StepPerformer):
         if new_column_header in prev_state.dfs[sheet_index].keys():
             raise make_column_exists_error(new_column_header)
 
-        # If the user has deleted the entire column header entirely, this is very likely
+        # If the user has deleted the column header entirely, this is very likely
         # a mistake and not something they meant to do... so we just don't make any edits
         # and don't throw an error
         if new_column_header == '':
@@ -98,7 +98,6 @@ class RenameColumnStepPerformer(StepPerformer):
         df_name = post_state.df_names[sheet_index]
         old_column_header = prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)
 
-        
         if level is not None:
             transpiled_old_value = column_header_to_transpiled_code(execution_data['old_level_value'] if execution_data else '')
             transpiled_new_value = column_header_to_transpiled_code(new_column_header)
@@ -132,6 +131,17 @@ class RenameColumnStepPerformer(StepPerformer):
             return f'Renamed {column_id} to {new_column_header}'
         else:
             return f'Renamed header at level {level} to {new_column_header}'
+    
+    @classmethod
+    def get_modified_dataframe_indexes( # type: ignore
+        cls, 
+        sheet_index: int,
+        column_id: str,
+        new_column_header: str,
+        level=None,
+        **params
+    ) -> Set[int]:
+        return {sheet_index}
 
 
 def rename_column_headers_in_state(
