@@ -5,7 +5,7 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import deepcopy
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Set, Tuple
 
 from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
@@ -91,10 +91,10 @@ class ReorderColumnStepPerformer(StepPerformer):
         new_column_index = get_valid_index(prev_state.dfs, sheet_index, new_column_index)
         df_name = post_state.df_names[sheet_index]
 
-        # get columns in df
+        # Get columns in df
         columns_list_line = f'{df_name}_columns = [col for col in {df_name}.columns if col != {transpiled_column_header}]'
 
-        # insert column into correct location 
+        # Insert column into correct location 
         insert_line = f'{df_name}_columns.insert({new_column_index}, {transpiled_column_header})'
         
         # Apply reorder line
@@ -115,6 +115,16 @@ class ReorderColumnStepPerformer(StepPerformer):
             df_name = df_names[sheet_index]
             return f'Reordered {column_id} in {df_name}'
         return f'Reordered {column_id}'
+    
+    @classmethod
+    def get_modified_dataframe_indexes( # type: ignore
+        cls, 
+        sheet_index: int,
+        column_id: str,
+        new_column_index: int,
+        **params
+    ) -> Set[int]:
+        return {sheet_index}
 
 
 def _execute_reorder_column(df, column_header, new_column_index):
