@@ -8,7 +8,7 @@ import pandas as pd
 
 from copy import deepcopy
 from mitosheet.step_performers.step_performer import StepPerformer
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Set, Tuple
 from mitosheet.state import State
 from mitosheet.sheet_functions.types.utils import get_mito_type
 from mitosheet.topological_sort import creates_circularity, subgraph_from_starting_column_id, topological_sort_columns
@@ -185,6 +185,17 @@ class SetColumnFormulaStepPerformer(StepPerformer):
             return f'Set {column_id} in {df_name} to {new_formula}'
         return f'Set {column_id} to {new_formula}'
 
+    @classmethod
+    def get_modified_dataframe_indexes( # type: ignore
+        cls, 
+        sheet_index: int,
+        column_id: str,
+        old_formula: str,
+        new_formula: str,
+        **params
+    ) -> Set[int]:
+        return {sheet_index}
+
 
 def _update_column_formula_in_step(
         post_state: State,
@@ -301,7 +312,7 @@ def get_details_from_operator_type_error(error):
         return (operator, arg_one_type, arg_two_type)
     # Handle case where pandas dataframes are part of the operator, for a concatenate
     if error_message.startswith('can only concatenate str'):
-        # We cannot tell the ordered here (e.g. we don't know if a string was concated
+        # We cannot tell the order here (e.g. we don't know if a string was concated
         # to an integer, or the other way around) b/c the error doesn't say so, so we just
         # do our best 
         other_type = error_message.split('"')[1]
