@@ -5,7 +5,7 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import copy
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Set, Tuple
 
 from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
@@ -58,6 +58,7 @@ class DataframeDeleteStepPerformer(StepPerformer):
         post_state.column_python_code.pop(sheet_index)
         post_state.column_evaluation_graph.pop(sheet_index)
         post_state.column_filters.pop(sheet_index)
+        post_state.column_format_types.pop(sheet_index)
         post_state.dfs.pop(sheet_index)
         post_state.df_names.pop(sheet_index)
         post_state.df_sources.pop(sheet_index)
@@ -84,3 +85,12 @@ class DataframeDeleteStepPerformer(StepPerformer):
         **params
     ) -> str:
         return f'Deleted dataframe {old_dataframe_name}'
+    
+    @classmethod
+    def get_modified_dataframe_indexes( # type: ignore
+        cls, 
+        sheet_index: int,
+        old_dataframe_name: str,
+        **params
+    ) -> Set[int]:
+        return set() # Redo all of them, as order shifts
