@@ -5,7 +5,7 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import copy
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Set, Tuple
 
 from mitosheet.state import DATAFRAME_SOURCE_DUPLICATED, State
 from mitosheet.step_performers.step_performer import StepPerformer
@@ -49,7 +49,9 @@ class DataframeDuplicateStepPerformer(StepPerformer):
         # Execute the step
         df_copy = post_state.dfs[sheet_index].copy(deep=True)
         new_name = get_first_unused_dataframe_name(post_state.df_names, post_state.df_names[sheet_index] + '_copy')
-        post_state.add_df_to_state(df_copy, DATAFRAME_SOURCE_DUPLICATED, df_name=new_name)
+        # Copy the formatting to the new sheet
+        format_types = post_state.column_format_types[sheet_index].copy()
+        post_state.add_df_to_state(df_copy, DATAFRAME_SOURCE_DUPLICATED, df_name=new_name, format_types=format_types)
 
         return post_state, None
 
@@ -78,3 +80,11 @@ class DataframeDuplicateStepPerformer(StepPerformer):
             new_df_name = df_names[len(df_names) - 1]
             return f'Duplicated {old_df_name} to {new_df_name}'
         return f'Duplicated a df'
+    
+    @classmethod
+    def get_modified_dataframe_indexes( # type: ignore
+        cls, 
+        sheet_index: int,
+        **params
+    ) -> Set[int]:
+        return {-1}
