@@ -5,7 +5,7 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import copy
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Set, Tuple
 
 from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
@@ -84,4 +84,14 @@ class DataframeRenameStepPerformer(StepPerformer):
         df_names=None,
         **params
     ) -> str:
-        return f'Renamed {old_dataframe_name} to {new_dataframe_name}'
\ No newline at end of file
+        return f'Renamed {old_dataframe_name} to {new_dataframe_name}'
+
+    @classmethod
+    def get_modified_dataframe_indexes( # type: ignore
+        cls, 
+        sheet_index: int,
+        old_dataframe_name: str,
+        new_dataframe_name: str,
+        **params
+    ) -> Set[int]:
+        return {sheet_index}
\ No newline at end of file
