@@ -3,9 +3,11 @@
 
 # Copyright (c) Mito.
 # Distributed under the terms of the Modified BSD License.
+
 from copy import deepcopy
+from typing import Any, Dict, List, Optional, Set, Union
+
 from mitosheet.state import State
-from typing import Any, Dict, List, Optional, Union
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.errors import (
     make_no_sheet_error,
@@ -119,4 +121,14 @@ class DropDuplicatesStepPerformer(StepPerformer):
         if df_names is not None:
             df_name = df_names[sheet_index]
             return f'Drop duplicates in {df_name}'
-        return f'Drop duplicates'
\ No newline at end of file
+        return f'Drop duplicates'
+
+    @classmethod
+    def get_modified_dataframe_indexes( # type: ignore
+        cls, 
+        sheet_index: int,
+        column_ids: List[str],
+        keep: str,
+        **params
+    ) -> Set[int]:
+        return {sheet_index}
\ No newline at end of file
