@@ -3,17 +3,16 @@
 
 # Copyright (c) Mito.
 
-
 from copy import deepcopy
 import functools
-from mitosheet.sheet_functions.types.utils import get_mito_type
-from mitosheet.step_performers.step_performer import StepPerformer
-from mitosheet.state import State
 from numbers import Number
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Set, Tuple
 import pandas as pd
 from datetime import date
 
+from mitosheet.sheet_functions.types.utils import get_mito_type
+from mitosheet.step_performers.step_performer import StepPerformer
+from mitosheet.state import State
 from mitosheet.sheet_functions.types import (
     BOOLEAN_SERIES,
     DATETIME_SERIES,
@@ -199,7 +198,6 @@ FILTER_FORMAT_STRING_MULTIPLE_VALUES_DICT = {
     }
 }
 
-
 # If there are multiple conditions, we combine them together, with the
 # given operator in the middle
 OPERATOR_SIGNS = {
@@ -272,7 +270,7 @@ class FilterStepPerformer(StepPerformer):
             filters
         )
 
-        # keep track of which columns are filtered
+        # Keep track of which columns are filtered
         post_state.column_filters[sheet_index][column_id]['operator'] = operator
         post_state.column_filters[sheet_index][column_id]['filters'] = filters
 
@@ -351,6 +349,17 @@ class FilterStepPerformer(StepPerformer):
             return f'Filtered {column_id} in {df_name}'
         return f'Filtered {column_id}'
 
+    @classmethod
+    def get_modified_dataframe_indexes( # type: ignore
+        cls, 
+        sheet_index: int,
+        column_id: str,
+        operator: str,
+        filters,
+        **params
+    ) -> Set[int]:
+        return {sheet_index}
+
 
 def get_applied_filter(df, column_header, filter_):
     """
@@ -380,7 +389,7 @@ def get_applied_filter(df, column_header, filter_):
         if condition not in STRING_FILTER_CONDITIONS:
             raise Exception(f'Invalid condition passed to string filter {condition}')
 
-        # Check that the value is the valid
+        # Check that the value is valid
         if not isinstance(value, str):
             raise make_invalid_filter_error(value, STRING_SERIES)
 
@@ -397,7 +406,7 @@ def get_applied_filter(df, column_header, filter_):
         if condition not in NUMBER_FILTER_CONDITIONS:
             raise Exception(f'Invalid condition passed to number filter {condition}')
         
-        # Check that the value is the valid
+        # Check that the value is valid
         if not isinstance(value, Number):
             raise make_invalid_filter_error(value, NUMBER_SERIES)
 
@@ -445,7 +454,7 @@ def get_applied_filter(df, column_header, filter_):
 def combine_filters(operator, filters):
 
     def filter_reducer(filter_one, filter_two):
-        # helper for combining filters based on the operations
+        # Helper for combining filters based on the operations
         if operator == 'Or':
             return (filter_one) | (filter_two)
         elif operator == 'And':
@@ -573,10 +582,10 @@ def create_filter_string_for_condition(condition, mito_filters, df_name, column_
     if len(filters_with_condition) == 0:
         return ''
     elif len(filters_with_condition) == 1:
-        # use the single filter condition
+        # Use the single filter condition
         return get_single_filter_string(df_name, column_header, filters_with_condition[0])
     elif len(filters_with_condition) > 1:
-        # use the multiple filter condition
+        # Use the multiple filter condition
         return get_multiple_filter_string(df_name, column_header, operator, condition, column_mito_type, filters_with_condition)
     
     return ''
\ No newline at end of file
