@@ -4,11 +4,11 @@
 # Copyright (c) Mito.
 # Distributed under the terms of the Modified BSD License.
 
-from mitosheet.utils import get_valid_dataframe_name
 from copy import copy
-from typing import Any, Dict, List, Optional, Tuple
-
+from typing import Any, Dict, List, Optional, Set, Tuple
 import pandas as pd
+
+from mitosheet.utils import get_valid_dataframe_name
 from mitosheet.state import DATAFRAME_SOURCE_IMPORTED, State
 from mitosheet.step_performers.step_performer import StepPerformer
 
@@ -122,4 +122,15 @@ class ExcelImportStepPerformer(StepPerformer):
         df_names=None,
         **params
     ) -> str:
-        return f'Imported {file_name}'
\ No newline at end of file
+        return f'Imported {file_name}'
+
+    @classmethod
+    def get_modified_dataframe_indexes( # type: ignore
+        cls, 
+        file_name: str,
+        sheet_names: List[str],
+        has_headers: bool,
+        use_deprecated_id_algorithm: bool=False,
+        **params
+    ) -> Set[int]:
+        return {-1} # changes the new dataframe(s - there might be multiple made in this step)
\ No newline at end of file
