@@ -7,13 +7,13 @@
 import csv
 import json
 from os.path import normpath, basename
-from mitosheet.utils import get_valid_dataframe_names
 import os
 from copy import copy
-from typing import Any, Dict, List, Optional, Tuple
-
+from typing import Any, Dict, List, Optional, Set, Tuple
 import chardet
 import pandas as pd
+
+from mitosheet.utils import get_valid_dataframe_names
 from mitosheet.errors import make_is_directory_error
 from mitosheet.state import DATAFRAME_SOURCE_IMPORTED, State
 from mitosheet.step_performers.step_performer import StepPerformer
@@ -124,6 +124,15 @@ class SimpleImportStepPerformer(StepPerformer):
         **params
     ) -> str:
         return f'Imported {", ".join(file_names)}'
+    
+    @classmethod
+    def get_modified_dataframe_indexes( # type: ignore
+        cls, 
+        file_names: List[str],
+        use_deprecated_id_algorithm: bool=False,
+        **params
+    ) -> Set[int]:
+        return {-1} # changes the new dataframe(s - there might be multiple made in this step)
 
 
 def generate_read_csv_code(file_name, df_name, delimeter, encoding):
@@ -143,7 +152,7 @@ def generate_read_csv_code(file_name, df_name, delimeter, encoding):
         # If there is a delimeter for this file, we use it
         return f'{df_name} = pd.read_csv(r\'{file_name}\', sep=\'{delimeter}\')'
     else:
-        # We don't add or encoding if they are the default.
+        # We don't add or encoding if they are the Default.
         return f'{df_name} = pd.read_csv(r\'{file_name}\')'
 
 
@@ -162,12 +171,18 @@ def read_csv_get_delimeter_and_encoding(file_name: str):
         df = pd.read_csv(file_name, sep=delimeter)
     except UnicodeDecodeError:
         # If we have an encoding error, try and get the encoding
-        encoding = guess_encoding(file_name)
-        delimeter = guess_delimeter(file_name, encoding=encoding)
+        try: 
+            encoding = guess_encoding(file_name)
+            delimeter = guess_delimeter(file_name, encoding=encoding)
 
-        # Read the file as dataframe 
-        df = pd.read_csv(file_name, sep=delimeter, encoding=encoding)
-    
+            # Read the file as dataframe 
+            df = pd.read_csv(file_name, sep=delimeter, encoding=encoding)
+        except: 
+            # Sometimes guess_encoding, guesses 'ascii' when we want 'latin-1', 
+            # so if guess_encoding fails, we try latin-1
+            encoding = 'latin-1'
+            df = pd.read_csv(file_name, sep=delimeter, encoding=encoding)
+        
     return df, delimeter, encoding
 
 
