@@ -6,13 +6,16 @@
 
 
 from copy import copy
+from typing import Any, Dict, List, Optional, Set, Tuple
+
 from mitosheet.errors import make_incompatible_merge_headers_error, make_incompatible_merge_key_error
-from typing import Any, Dict, List, Optional, Tuple
 from mitosheet.state import DATAFRAME_SOURCE_MERGED, State
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.transpiler.transpile_utils import column_header_list_to_transpiled_code, column_header_to_transpiled_code
 
-
+LOOKUP = 'lookup'
+UNIQUE_IN_LEFT = 'unique in left'
+UNIQUE_IN_RIGHT = 'unique in right'
 
 class MergeStepPerformer(StepPerformer):
     """
@@ -53,7 +56,6 @@ class MergeStepPerformer(StepPerformer):
         **params
     ) -> Tuple[State, Optional[Dict[str, Any]]]:
 
-    
         merge_key_one = prev_state.column_ids.get_column_header_by_id(sheet_index_one, merge_key_column_id_one)
         merge_key_two = prev_state.column_ids.get_column_header_by_id(sheet_index_two, merge_key_column_id_two)
 
@@ -101,7 +103,7 @@ class MergeStepPerformer(StepPerformer):
         selected_columns_one = prev_state.column_ids.get_column_headers_by_ids(sheet_index_one, selected_column_ids_one)
         selected_columns_two = prev_state.column_ids.get_column_headers_by_ids(sheet_index_two, selected_column_ids_two)
 
-        # update df indexes to start at 1
+        # Update df indexes to start at 1
         df_one_name = post_state.df_names[sheet_index_one]
         df_two_name = post_state.df_names[sheet_index_two]
         df_new_name = post_state.df_names[len(post_state.dfs) - 1]
@@ -136,15 +138,23 @@ class MergeStepPerformer(StepPerformer):
         df_one_to_merge = df_one_name if len(deleted_columns_one) == 0 else f'{df_one_name}_tmp'
         df_two_to_merge = temp_df_name if len(deleted_columns_two) == 0 else f'{df_two_name}_tmp'
 
-        # We insist column names are unique in dataframes, so while we default the suffixes to be the dataframe
-        # names
+        # We insist column names are unique in dataframes, so we default the suffixes to be the dataframe names
         suffix_one = df_one_name
         suffix_two = df_two_name if df_two_name != df_one_name else f'{df_two_name}_2'
 
         # Finially append the merge
-        merge_code.append(
-            f'{df_new_name} = {df_one_to_merge}.merge({df_two_to_merge}, left_on=[{column_header_to_transpiled_code(merge_key_one)}], right_on=[{column_header_to_transpiled_code(merge_key_two)}], how=\'{how_to_use}\', suffixes=[\'_{suffix_one}\', \'_{suffix_two}\'])'
-        )
+        if how == UNIQUE_IN_LEFT:
+            merge_code.append(
+                f'{df_new_name} = {df_one_to_merge}.copy(deep=True)[~{df_one_to_merge}["{merge_key_one}"].isin({df_two_to_merge}["{merge_key_two}"])]'
+            )
+        elif how == UNIQUE_IN_RIGHT:
+            merge_code.append(
+                f'{df_new_name} = {df_two_to_merge}.copy(deep=True)[~{df_two_to_merge}["{merge_key_two}"].isin({df_one_to_merge}["{merge_key_one}"])]'
+            )
+        else:      
+            merge_code.append(
+                f'{df_new_name} = {df_one_to_merge}.merge({df_two_to_merge}, left_on=[{column_header_to_transpiled_code(merge_key_one)}], right_on=[{column_header_to_transpiled_code(merge_key_two)}], how=\'{how_to_use}\', suffixes=[\'_{suffix_one}\', \'_{suffix_two}\'])'
+            )
 
         # And then return it
         return merge_code
@@ -167,6 +177,19 @@ class MergeStepPerformer(StepPerformer):
             df_two_name = df_names[sheet_index_two]
             return f'Merged {df_one_name} and {df_two_name}'
         return f'Merged dataframes {sheet_index_one} and {sheet_index_two}'
+    
+    @classmethod
+    def get_modified_dataframe_indexes( # type: ignore
+        cls, 
+        how: str,
+        sheet_index_one: int,
+        merge_key_column_id_one: str,
+        selected_column_ids_one: List[str],
+        sheet_index_two: int,
+        merge_key_column_id_two: str,
+        selected_column_ids_two: List[str],
+    ) -> Set[int]:
+        return {-1}
 
 def _execute_merge(
         dfs, 
@@ -214,6 +237,11 @@ def _execute_merge(
     suffix_two = df_two_name if df_two_name != df_one_name else f'{df_two_name}_2'
 
     try:
-        return df_one_cleaned.merge(df_two_cleaned, left_on=[merge_key_one], right_on=[merge_key_two], how=how_to_use, suffixes=[f'_{suffix_one}', f'_{suffix_two}'])
+        if how == UNIQUE_IN_LEFT:
+            return df_one_cleaned.copy(deep=True)[~df_one_cleaned[merge_key_one].isin(df_two_cleaned[merge_key_two])]
+        if how == UNIQUE_IN_RIGHT:
+            return df_two_cleaned.copy(deep=True)[~df_two_cleaned[merge_key_two].isin(df_one_cleaned[merge_key_one])]
+        else:
+            return df_one_cleaned.merge(df_two_cleaned, left_on=[merge_key_one], right_on=[merge_key_two], how=how_to_use, suffixes=[f'_{suffix_one}', f'_{suffix_two}'])
     except ValueError:
         raise make_incompatible_merge_key_error(error_modal=False)
