@@ -4,12 +4,11 @@
 # Copyright (c) Mito.
 # Distributed under the terms of the Modified BSD License.
 
-
 from copy import copy
-from mitosheet.column_headers import flatten_column_header
-from typing import Any, Dict, List, Optional, Tuple
-
+from typing import Any, Dict, List, Optional, Set, Tuple
 import pandas as pd
+
+from mitosheet.column_headers import flatten_column_header
 from mitosheet.errors import (make_invalid_aggregation_error,
                               make_invalid_pivot_error, make_no_column_error)
 from mitosheet.state import DATAFRAME_SOURCE_PIVOTED, State
@@ -128,6 +127,7 @@ class PivotStepPerformer(StepPerformer):
                 new_df, 
                 DATAFRAME_SOURCE_PIVOTED,
                 sheet_index=destination_sheet_index,
+                df_name=get_new_pivot_df_name(post_state, sheet_index),
                 use_deprecated_id_algorithm=use_deprecated_id_algorithm
             )
 
@@ -160,7 +160,7 @@ class PivotStepPerformer(StepPerformer):
     ) -> List[str]:
         old_df_name = post_state.df_names[sheet_index]
         if destination_sheet_index is None:
-            new_df_name = f'df{len(post_state.dfs)}'
+            new_df_name = post_state.df_names[-1]
         else:
             # If we're repivoting an existing pivot table, we have
             # to make sure to overwrite the correct pivot table 
@@ -216,11 +216,27 @@ class PivotStepPerformer(StepPerformer):
             return f'Pivoted {old_df_name} into {new_df_name}'
         return f'Pivoted dataframe {sheet_index}'
 
+    @classmethod
+    def get_modified_dataframe_indexes( # type: ignore
+        cls, 
+        sheet_index,
+        pivot_rows_column_ids,
+        pivot_columns_column_ids,
+        values_column_ids_map,
+        destination_sheet_index=None,
+        use_deprecated_id_algorithm: bool=False,
+        **params
+    ) -> Set[int]:
+        if destination_sheet_index: # If editing an existing sheet, that is what is changed
+            return {destination_sheet_index}
+        return {-1}
+    
+
 
 def values_to_functions(values):
     """
-    Helper function for turning the values mapping sent by the frontend to the values
-    mapping to functions that can actually be passed to the pandas pivot function
+    Helper function for turning the values mapping sent by the frontend to 
+    the value map of functions that can actually be passed to the pandas pivot function
     """
     new_values = dict()
 
@@ -322,3 +338,17 @@ def build_args_code(
         args.append(f'aggfunc={values_to_functions_code(values)}')
         
     return NEWLINE_TAB.join(args)
+
+def get_new_pivot_df_name (post_state, sheet_index): 
+    """
+    Creates the name for the new pivot table sheet using the format
+    {source_sheet_name}_{pivot} or {source_sheet_name}_{pivot}_1, etc. 
+    if the pivot table name already exists. 
+    """
+    new_df_name_original = post_state.df_names[sheet_index] + '_pivot'
+    curr_df_name = new_df_name_original
+    multiple_sheet_indicator = 1
+    while curr_df_name in post_state.df_names:
+        curr_df_name = f'{new_df_name_original}_{multiple_sheet_indicator}'
+        multiple_sheet_indicator += 1
+    return curr_df_name
