@@ -5,9 +5,9 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import deepcopy
-from typing import Any, Dict, List, Optional, Tuple, Union
-
+from typing import Any, Dict, List, Optional, Set, Tuple, Union
 import numpy as np
+
 from mitosheet.errors import make_cast_value_to_type_error, make_no_column_error
 from mitosheet.sheet_functions.types import SERIES_CONVERSION_FUNCTIONS
 from mitosheet.sheet_functions.types.utils import (BOOLEAN_SERIES,
@@ -163,13 +163,25 @@ class SetCellValueStepPerformer(StepPerformer):
             return f'Set column {column_id} at index {row_index} in {df_name} to {new_value}'
         return f'Set column {column_id} at index {row_index} to {new_value}'
 
+    @classmethod
+    def get_modified_dataframe_indexes( # type: ignore
+        cls, 
+        sheet_index: int,
+        column_id: str,
+        row_index: int,
+        old_value: str,
+        new_value: Union[str, None],
+        **params
+    ) -> Set[int]:
+        return {sheet_index}
+
 
 def cast_value_to_type(value: Union[str, None], mito_series_type: str):
     """
     Helper function for converting a value into the correct type for the 
     series that it is going to be added to. 
     """
-    # If the user it trying to make the value None, let them.
+    # If the user is trying to make the value None, let them.
     if is_none_type(value) or value is None:
         return None
 
