@@ -3,9 +3,11 @@
 
 # Copyright (c) Mito.
 # Distributed under the terms of the Modified BSD License.
+
 from copy import deepcopy
+from typing import Any, Dict, List, Optional, Set, Tuple
+
 from mitosheet.state import State
-from typing import Any, Dict, List, Optional, Tuple
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.errors import (
     make_invalid_sort_error
@@ -106,4 +108,14 @@ class SortStepPerformer(StepPerformer):
         if df_names is not None:
             df_name = df_names[sheet_index]
             return f'Sorted {column_id} in {df_name} in {sort_direction} order'
-        return f'Sorted {column_id} in {sort_direction} order'
\ No newline at end of file
+        return f'Sorted {column_id} in {sort_direction} order'
+
+    @classmethod
+    def get_modified_dataframe_indexes( # type: ignore
+        cls, 
+        sheet_index: int,
+        column_id: str,
+        sort_direction: str,
+        **params
+    ) -> Set[int]:
+        return {sheet_index}
\ No newline at end of file
