@@ -1,10 +1,10 @@
 from abc import ABC, abstractmethod
 from mitosheet.state import State
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Set, Tuple
  
 class StepPerformer(ABC, object):
     """
-    The abstract base class for a step generator, which are the set
+    The abstract base class for a step performer, which are the set
     of classes that execute, transpile, and describe steps. 
     """
 
@@ -78,4 +78,19 @@ class StepPerformer(ABC, object):
         Describes the step in a single sentence, usually for comments or for presentation
         to the user in the frontend.
         """
+        pass
+
+    @classmethod
+    @abstractmethod
+    def get_modified_dataframe_indexes(cls, **params) -> Set[int]:
+        """
+        Returns a set of all the sheet indexes that were modified
+        by this step.
+
+        If it returns an empty set, then this step
+        modified every dataframe.
+
+        If it returned -1, then it modified all new dataframes (on
+        the left side of the dfs array).
+        """
         pass
\ No newline at end of file
