@@ -16,7 +16,7 @@ from mitosheet.step import Step
 from mitosheet.step_performers import EVENT_TYPE_TO_STEP_PERFORMER
 from mitosheet.updates import UPDATES
 from mitosheet.preprocessing import PREPROCESS_STEP_PERFORMERS
-from mitosheet.utils import dfs_to_json, get_new_id
+from mitosheet.utils import dfs_to_array_for_json, get_new_id
 from mitosheet.transpiler.transpile import transpile
 from mitosheet.data_in_mito import DataTypeInMito, get_data_type_in_mito
 
@@ -57,7 +57,6 @@ def execute_step_list_from_index(step_list: List[Step], start_index=None):
     new_step_list = step_list[:start_index + 1] 
     last_valid_step = step_list[start_index]
 
-
     for partial_index, step in enumerate(step_list[start_index + 1:]):
         step_index = partial_index + start_index + 1
         # If we're skipping a step, add it to the new step list (since we don't
@@ -82,6 +81,46 @@ def execute_step_list_from_index(step_list: List[Step], start_index=None):
     
     return new_step_list
 
+def get_modified_sheet_indexes(steps: List[Step], starting_step_index: int, ending_step_index: int) -> Set[int]:
+    """
+    Returns a best guess for which sheets have been modified starting at
+    starting_step_index and ending at (and including) ending_step_index.
+
+    This is a best guess for caching reasons, and so may return sheets that
+    have in fact not been modified. If a sheet index has been modified, it should
+    always be returned.
+    """
+    # If only one step has been performed, we can calculate the modified sheet indexes,
+    # otherwise we just say all of them (undo, replay might interact weird) 
+    if starting_step_index == ending_step_index - 1:
+        step = steps[ending_step_index]
+        modified_indexes = step.step_performer.get_modified_dataframe_indexes(**step.params)
+
+        # If the set is empty, then we modified everything
+        if len(modified_indexes) == 0:
+            modified_indexes = {j for j in range(len(step.dfs))}
+        # If -1 is modified, then all new dataframes are modified, which
+        # if nothing new was created, means there was a live updated event, 
+        # and so we should just take the last element
+        elif -1 in modified_indexes:
+            prev_step = steps[ending_step_index - 1]
+            modified_indexes.remove(-1)
+
+            if len(prev_step.dfs) != len(step.dfs):
+                modified_indexes.update({
+                    j for j in range(
+                        len(prev_step.dfs),
+                        len(step.dfs)
+                    )
+                })
+            else:
+                modified_indexes.add(len(step.dfs) - 1)            
+    else: 
+        modified_indexes = {i for i in range(len(steps[ending_step_index].dfs))}
+    
+    return modified_indexes
+
+
 class StepsManager():
     """
     The StepsManager holds the list of the steps, and makes sure 
@@ -174,6 +213,12 @@ class StepsManager():
         # which means you can never see before the initalize step
         self.curr_step_idx = 0
 
+        # We also cache some of the sheet data in a form suitable to turn
+        # into json, so that we can package it and send it to the front-end
+        # faster and with less work
+        self.saved_sheet_data = []
+        self.last_step_index_we_wrote_sheet_json_on = 0
+
     @property
     def curr_step(self) -> Step:
         """
@@ -194,13 +239,21 @@ class StepsManager():
     def sheet_data_json(self) -> str:
         """
         sheet_json contains a serialized representation of the data
-        frames that is then fed into the ag-grid in the front-end. 
+        frames that is then fed into the Endo in the front-end. 
 
-        NOTE: we only display the _first_ 2,000 rows of the dataframe
+        NOTE: we only display the _first_ 1,500 rows of the dataframe
         for speed reasons. This results in way less data getting 
         passed around
         """
-        return dfs_to_json(
+        modified_sheet_indexes = get_modified_sheet_indexes(
+            self.steps, 
+            self.last_step_index_we_wrote_sheet_json_on, 
+            self.curr_step_idx
+        )
+
+        array = dfs_to_array_for_json(
+            modified_sheet_indexes,
+            self.saved_sheet_data,
             self.curr_step.dfs,
             self.curr_step.df_names,
             self.curr_step.df_sources,
@@ -208,8 +261,14 @@ class StepsManager():
             self.curr_step.column_filters,
             self.curr_step.column_type,
             self.curr_step.column_ids,
+            self.curr_step.column_format_types
         )
 
+        self.saved_sheet_data = array
+        self.last_step_index_we_wrote_sheet_json_on = self.curr_step_idx
+
+        return json.dumps(array)
+
     @property
     def analysis_data_json(self):
         return json.dumps({
