@@ -1,23 +1,19 @@
-#!/usr/bin/env python
-# coding: utf-8
-
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
-import sys
-from typing import Any, Dict
-
 import atheris
 import pandas as pd
+import sys
+
 
 with atheris.instrument_imports():
-    import mitosheet
+    from mitosheet.tests.test_utils import MitoWidgetTestWrapper
     from mitosheet.step_performers.filter import FC_NUMBER_EXACTLY
-    from mitosheet.tests.test_utils import (MitoWidgetTestWrapper,
-                                            create_mito_wrapper_dfs)
+    import mitosheet
+    from mitosheet.tests.test_utils import create_mito_wrapper_dfs
+    from mitosheet.sheet_functions.types import (
+        NUMBER_SERIES,
+    )
 
 
-
-def get_random_event(fdp: atheris.FuzzedDataProvider) -> Dict[str, Any]:
+def get_random_event(fdp):
     """
     Takes a fuzz data provider, returns a random
     event to send to the backend.
@@ -36,7 +32,7 @@ def get_random_event(fdp: atheris.FuzzedDataProvider) -> Dict[str, Any]:
     }
 
 
-def send_random_event(mito: MitoWidgetTestWrapper, fdp: atheris.FuzzedDataProvider) -> None:
+def send_random_event(mito: MitoWidgetTestWrapper, fdp):
 
     random_sheet_index = fdp.PickValueInList(list(range(len(mito.dfs))))
     random_existing_column_header = fdp.PickValueInList(list(mito.dfs[random_sheet_index].keys()))
@@ -97,6 +93,7 @@ def send_random_event(mito: MitoWidgetTestWrapper, fdp: atheris.FuzzedDataProvid
             random_sheet_index,
             random_column_header,
             'And',
+            NUMBER_SERIES,
             FC_NUMBER_EXACTLY,
             1
         )
@@ -181,8 +178,8 @@ def TestMito(data):
     for _ in range(NUM_EVENTS):
         send_random_event(mito, fdp)
 
-    print("NUM STEPS:", len(mito.steps_including_skipped))
+    print("NUM STEPS:", len(mito.steps))
 
 
 atheris.Setup(sys.argv, TestMito)
-atheris.Fuzz()
+atheris.Fuzz()
\ No newline at end of file
