@@ -24,6 +24,7 @@ from mitosheet.step_performers import (
     DeleteColumnStepPerformer,
     RenameColumnStepPerformer,
     ChangeColumnDtypeStepPerformer,
+    ChangeColumnFormatStepPerformer,
     SimpleImportStepPerformer,
     DataframeDeleteStepPerformer,
     DataframeDuplicateStepPerformer,
@@ -127,6 +128,13 @@ def test_params_static():
         'change_column_dtype'
     )
 
+    check_step(
+        ChangeColumnFormatStepPerformer,
+        1,
+        'change_column_format'
+    )
+
+
     check_step(
         SimpleImportStepPerformer,
         2,
@@ -175,7 +183,7 @@ def test_params_static():
         'drop_duplicates'
     )
 
-    assert len(STEP_PERFORMERS) == 18
+    assert len(STEP_PERFORMERS) == 19
 
 
 def get_fake_param(param_name):
