@@ -8,16 +8,15 @@
 This file contains helpful functions and classes for testing operations.
 """
 
-from typing import List
-from mitosheet.utils import get_new_id
-from typing import List
+import json
 from functools import wraps
+from typing import Dict, List
 
 import pandas as pd
 from mitosheet.mito_widget import MitoWidget, sheet
 from mitosheet.transpiler.transpile import transpile
-from mitosheet.utils import get_new_id
-from mitosheet.api.get_sheet_data import get_sheet_data
+from mitosheet.utils import dfs_to_array_for_json, get_new_id
+
 
 def decorate_all_functions(function_decorator):
     """
@@ -45,6 +44,9 @@ def check_dataframes_equal(test_wrapper):
     """
     Tests that the dataframes in the widget state container equal
     to those that are the result of the executed code. 
+
+    Also makes sure that the sheet json that is saved is the correct
+    sheet json that is used in the sheet
     """
 
     # The only dataframes we want to define apriori are the dataframes that
@@ -90,6 +92,21 @@ def check_dataframes_equal(test_wrapper):
         original_dfs
     )
 
+    # We then check that the sheet data json that is saved by the widget, which 
+    # notably uses caching, does not get incorrectly cached and is written correctly
+    assert test_wrapper.mito_widget.sheet_data_json == json.dumps(dfs_to_array_for_json(
+        set(i for i in range(len(test_wrapper.mito_widget.steps_manager.curr_step.dfs))),
+        [],
+        test_wrapper.mito_widget.steps_manager.curr_step.dfs,
+        test_wrapper.mito_widget.steps_manager.curr_step.df_names,
+        test_wrapper.mito_widget.steps_manager.curr_step.df_sources,
+        test_wrapper.mito_widget.steps_manager.curr_step.column_spreadsheet_code,
+        test_wrapper.mito_widget.steps_manager.curr_step.column_filters,
+        test_wrapper.mito_widget.steps_manager.curr_step.column_type,
+        test_wrapper.mito_widget.steps_manager.curr_step.column_ids,
+        test_wrapper.mito_widget.steps_manager.curr_step.column_format_types
+    ))
+
 
 class MitoWidgetTestWrapper:
     """
@@ -129,6 +146,10 @@ class MitoWidgetTestWrapper:
     def df_names(self):
         return self.mito_widget.steps_manager.curr_step.df_names
 
+    @property
+    def column_format_types(self):
+        return self.mito_widget.steps_manager.curr_step.column_format_types
+
     @check_transpiled_code_after_call
     def add_column(self, sheet_index: int, column_header: str, column_header_index=-1):
         """
@@ -270,8 +291,6 @@ class MitoWidgetTestWrapper:
             step_id=None
         ):
 
-        print(flatten_column_headers)
-
         rows_ids = [
             self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index, column_header)
             for column_header in pivot_rows
@@ -495,6 +514,32 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    @check_transpiled_code_after_call
+    def change_column_format(self, sheet_index: int, column_headers: List[str], new_format: Dict[str, str]):
+
+        column_ids = []
+        for column_header in column_headers: 
+            column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
+                sheet_index,
+                column_header
+            )
+            column_ids.append(column_id)
+
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'change_column_format_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'sheet_index': sheet_index,
+                    'column_ids': column_ids,
+                    'format_type': new_format
+                }
+            }
+        )
+
     @check_transpiled_code_after_call
     def simple_import(self, file_names: List[str]):
         return self.mito_widget.receive_message(
@@ -684,23 +729,6 @@ class MitoWidgetTestWrapper:
             }
         )
 
-    def get_sheet_data_str(self, sheet_index: int, starting_row_index: int=0):
-        """
-        Returns a series object of the given column, or a list if
-        as_list is True. 
-
-        Errors if the column does not exist. 
-        """
-        return get_sheet_data(
-            {
-                'event': 'api_call',
-                'id': get_new_id(),
-                'type': 'get_sheet_data',
-                'sheet_index': sheet_index,
-                'starting_row_index': starting_row_index
-            },
-            self.mito_widget.steps_manager
-        )
 
     def get_formula(self, sheet_index: int, column_header: str):
         """
@@ -728,7 +756,7 @@ class MitoWidgetTestWrapper:
 
     def get_value(self, sheet_index: int, column_header: str, row: int):
         """
-        Returns a value in a given dataframe at the a given
+        Returns a value in a given dataframe at the given
         index in a column. NOTE: the row is 1 indexed!
 
         Errors if the value does not exist
@@ -748,9 +776,6 @@ class MitoWidgetTestWrapper:
 
     
 
-
-        
-
 def create_mito_wrapper(sheet_one_A_data, sheet_two_A_data=None) -> MitoWidgetTestWrapper:
     """
     Returns a MitoWidgetTestWrapper instance wrapped around a MitoWidget
