@@ -5,7 +5,7 @@
 # Distributed under the terms of the Modified BSD License.
 
 """
-Appends a value to a specific feild, which is useful
+Appends a value to a specific field, which is useful
 for adding to lists in the user.json.
 """
 
@@ -20,7 +20,7 @@ APPEND_USER_FIELD_PARAMS = ['field', 'value']
 def execute_append_user_field_update(steps_manager, field, value):
     """
     The function responsible for appending value to the list
-    stored at field
+    stored at field.
     """
     field_values = get_user_field(field)
     if field_values == None: 
@@ -33,7 +33,7 @@ def execute_append_user_field_update(steps_manager, field, value):
     else:
         field_values.append(value)
     
-    # set the field to the new list
+    # Set the field to the new list
     set_user_field(field, field_values)
 
     # Identify just in case
