@@ -16,7 +16,7 @@ SET_USER_FIELD_EVENT = 'set_user_field_update'
 SET_USER_FIELD_PARAMS = ['field', 'value']
 
 
-def execute_set_user_field_update(wsc, field, value):
+def execute_set_user_field_update(steps_manager, field, value):
     """
     The function responsible for setting specific field values
     for the user.json file, and then reidentifying the user
