@@ -20,7 +20,7 @@ from mitosheet.user.db import MITO_FOLDER, USER_JSON_PATH, get_user_json_object,
 
 def is_user_json_exists_and_valid_json():
     """
-    Helper function that determines if the current user json both
+    Helper function that determines if the current user.json both
     exists and is valid json
     """
     if not os.path.exists(USER_JSON_PATH):
@@ -65,7 +65,7 @@ def initialize_user(identify=True):
     3. Updates the user.json file with any usage or upgrading, logging anything interesting.
     
     By default, also identifies the user, but may not do this in some cases (when identify
-    if False), as the user may just be turning logging off or something.
+    is False), as the user may just be turning logging off or something.
     """
     # Try to create the user.json file, if it does not already exist
     try_create_user_json_file()
