@@ -5,7 +5,7 @@ import os
 import json
 
 # Where all global .mito files are stored
-MITO_FOLDER = os.path.expanduser("~/.mito")
+MITO_FOLDER = os.path.join(os.path.expanduser("~"), '.mito')
 
 # The path of the user.json file
 USER_JSON_PATH = os.path.join(MITO_FOLDER, 'user.json')
