@@ -44,7 +44,7 @@ def is_pro():
     Helper function for returning if this is a
     pro deployment of mito
     """
-    return not get_user_field(UJ_MITOSHEET_PRO)  
+    return get_user_field(UJ_MITOSHEET_PRO)  
 
 
 def is_local_deployment():
