@@ -10,16 +10,17 @@ Contains helpful utility functions
 import json
 import re
 import uuid
-from os.path import basename, normpath
-from typing import Any, Dict, List, Match
+from typing import Any, Dict, List, Set
 
 import numpy as np
 import pandas as pd
 
 from mitosheet.column_headers import ColumnIDMap
-from mitosheet.sheet_functions.types.utils import (get_datetime_columns,
-                                                   get_float_columns,
-                                                   get_timedelta_columns)
+from mitosheet.sheet_functions.types.utils import get_float_dt_td_columns
+
+# We only send the first 1500 rows of a dataframe; note that this
+# must match this variable defined on the front-end
+MAX_ROWS = 1_500
 
 
 def get_first_unused_dataframe_name(existing_df_names: List[str], new_dataframe_name: str) -> str:
@@ -45,9 +46,9 @@ def get_valid_dataframe_name(existing_df_names: List[str], original_dataframe_na
     Given a string, turns it into a valid dataframe name.
     """
     # We get all the words from the original name, and append them with underscores
-    dataframe_name = '_'.join([
-        match.group() for match in re.finditer('\w+', original_dataframe_name)
-    ])
+    dataframe_name = '_'.join(filter(None, [
+        match.group() if match.group() != 'csv' and match.group() != 'xlsx' else '' for match in re.finditer('\w+', original_dataframe_name)
+    ]))
 
     # A valid variable name cannot be empty, or start with a number
     if len(dataframe_name) == 0 or dataframe_name[0].isdecimal():
@@ -73,44 +74,52 @@ def get_valid_dataframe_names(existing_df_names: List[str], original_df_names: L
     
     return final_names
 
-
-def dfs_to_json(
+def dfs_to_array_for_json(
+        modified_sheet_indexes: Set[int],
+        previous_array: List,
         dfs: List[pd.DataFrame],
         df_names: List[str],
         df_sources: List[str],
         column_spreadsheet_code_array: List[Dict[str, str]],
         column_filters_array: List[Dict[str, Any]],
         column_mito_types_array: List[Dict[str, str]],
-        column_ids: ColumnIDMap
-    ) -> str:
-    return json.dumps([
-        df_to_json_dumpsable(
-            df, 
-            df_names[sheet_index],
-            df_sources[sheet_index],
-            column_spreadsheet_code_array[sheet_index],
-            column_filters_array[sheet_index],
-            column_mito_types_array[sheet_index],
-            column_ids.column_header_to_column_id[sheet_index],
-            # NOTE: since we now lazy-load, we simply don't include any of the actual
-            # column data in the sheet data array that is passed to the frontend.
-            # Instead, this data is now loading in Endo.tsx, in the loadSheetData function
-            max_length=0
-        ) 
-        for sheet_index, df in enumerate(dfs)
-    ])
+        column_ids: ColumnIDMap,
+        column_format_types: List[Dict[str, Dict[str, str]]]
+    ) -> List:
+
+    new_array = []
+    for sheet_index, df in enumerate(dfs):
+        if sheet_index in modified_sheet_indexes:
+            new_array.append(
+                df_to_json_dumpsable(
+                    df, 
+                    df_names[sheet_index],
+                    df_sources[sheet_index],
+                    column_spreadsheet_code_array[sheet_index],
+                    column_filters_array[sheet_index],
+                    column_mito_types_array[sheet_index],
+                    column_ids.column_header_to_column_id[sheet_index],
+                    column_format_types[sheet_index],
+                    # We only send the first 1500 rows, and this must 
+                    max_length=MAX_ROWS,
+                ) 
+            )
+        else:
+            new_array.append(previous_array[sheet_index])
+
+    return new_array
 
 
 def df_to_json_dumpsable(
-        df: pd.DataFrame,
+        original_df: pd.DataFrame,
         df_name: str,
         df_source: str,
         column_spreadsheet_code: Dict[str, str],
         column_filters: Dict[str, Any],
         column_mito_types: Dict[str, str],
         column_headers_to_column_ids: Dict[Any, str],
-        max_length=2000, # How many items you want to display
-        starting_index=0
+        column_format_types: Dict[str, Dict[str, str]],
+        max_length=MAX_ROWS, # How many items you want to display
     ):
     """
     Returns a dataframe represented in a way that can be turned into a 
@@ -131,39 +140,35 @@ def df_to_json_dumpsable(
         columnIDsMap: ColumnIDsMap;
         columnSpreadsheetCodeMap: Record<string, string>;
         columnFiltersMap: ColumnFilterMap;
-        columnMitoTypeMap: ColumnMitoTypeMap
+        columnMitoTypeMap: ColumnMitoTypeMap;
         index: (string | number)[];
+        columnFormatTypeObjMap: ColumnFormatTypeObjMap;
     }
     """
 
-    (num_rows, num_columns) = df.shape 
+    (num_rows, num_columns) = original_df.shape 
 
-    if starting_index > 0 and starting_index < num_rows:
-        df = df.iloc[starting_index:]
+    if max_length is None:
+        df = original_df.copy(deep=True) 
+    else:
+        # we only show the first max_length rows!
+        df = original_df.head(n=max_length if max_length else num_rows).copy(deep=True)
 
-    # First, if the max_length is set, we get the head, and then 
-    # we make a copy (as we modify the df below)
-    # NOTE: we get the head first for efficiency reasons.
-    if max_length is not None:
-        df = df.head(n=max_length).copy(deep=True) # we only show the first max_length rows!
-    
+    float_columns, date_columns, timedelta_columns = get_float_dt_td_columns(df)
     # Second, we figure out which of the columns contain dates, and we
     # convert them to string columns (for formatting reasons).
     # NOTE: we don't use date_format='iso' in df.to_json call as it appends seconds to the object, 
     # see here: https://stackoverflow.com/questions/52730953/pandas-to-json-output-date-format-in-specific-form
-    date_columns = get_datetime_columns(df)
     for column_header in date_columns:
         df[column_header] = df[column_header].dt.strftime('%Y-%m-%d %X')
 
     # Third, we figure out which of the columns contain timedeltas, and 
     # we format the timedeltas as strings to make them readable
-    timedelta_columns = get_timedelta_columns(df)
     for column_header in timedelta_columns:
         df[column_header] = df[column_header].apply(lambda x: str(x))
 
     # Then, we get all the float columns and actually make them 
     # look like floating point values, by converting them to strings
-    float_columns = get_float_columns(df)
     for column_header in float_columns:
         # Convert the value to a string if it is a number, but leave it alone if its a NaN 
         # as to preserve the formatting of NaN values. 
@@ -188,7 +193,7 @@ def df_to_json_dumpsable(
         column_final_data = {
             'columnID': column_headers_to_column_ids[column_header],
             'columnHeader': column_header,
-            'columnDtype': str(df[column_header].dtype),
+            'columnDtype': str(original_df[column_header].dtype),
             'columnData': []
         }
         for row in json_obj['data']:
@@ -211,7 +216,8 @@ def df_to_json_dumpsable(
         'columnSpreadsheetCodeMap': column_spreadsheet_code,
         'columnFiltersMap': column_filters,
         'columnMitoTypeMap': column_mito_types,
-        'index': json_obj['index']
+        'index': json_obj['index'],
+        'columnFormatTypeObjMap': column_format_types
     }
 
 
